# frozen_string_literal: true

module WAG
  class Function
    include WAG::Encodable
    prepend WAG::Instructable

    attr_reader :label, :params

    def initialize(label = nil)
      @label = WAG::Label.from(label) if label
      @params = []
    end

    def param(label = nil, type)
      @params.push(WAG::Param.new(type, label))
    end

    def result(*types)
      return @result if types.empty?

      @result = WAG::Result.new(*types)
    end

    def to_sexpr
      [:func].tap do |func|
        func.push(@label.to_sexpr) if @label
        func.concat(@params.map(&:to_sexpr)) unless @params.empty?
        func.push(@result.to_sexpr) if @result
      end
    end
  end
end
