# frozen_string_literal: true

module WAG
  class Import
    include WAG::Encodable

    attr_reader :module_name, :name, :desc

    def initialize(module_name, name)
      @module_name = module_name
      @name = name
    end

    def func(label, &block)
      @desc = Function.new(label)
      @desc.instance_exec(&block) if block
      @desc
    end

    def global(label, type, &block)
      @desc = Global.new(label, type)
      @desc.instance_exec(&block) if block
      @desc
    end

    def memory(number, min = nil, max = nil, &block)
      @desc = Memory.new(number, min, max)
      @desc.instance_exec(&block) if block
      @desc
    end

    def table(number, type = :anyfunc, &block)
      @desc = Table.new(number, type)
      @desc.instance_exec(&block) if block
      @desc
    end

    def to_sexpr
      [:import, module_name, name, desc.to_sexpr]
    end
  end
end
