# frozen_string_literal: true

module WAG
  module Instructable
    # Define all the basic instructions.
    %i[unreachable nop block loop if else end br br_if br_table return call
       call_indirect drop select].each do |instruction_name|
      camelised_name = WAG::Inflector.inflector.camelize(instruction_name)
      define_method(instruction_name) do |*args, &block|
        instruction = WAG::Instruction.const_get(camelised_name).new(*args)
        instructions << instruction
        instruction.instance_exec(&block) if block
        instruction
      end
    end

    # Alias Ruby keywords because reasons.
    alias if_ if
    alias else_ else
    alias end_ end
    alias loop_ loop
    alias return_ return

    def f32
      WAG::F32Instructions.new(instructions)
    end

    def f64
      WAG::F64Instructions.new(instructions)
    end

    def local(*args)
      return WAG::LocalInstructions.new(instructions) if args.empty?

      instruction = WAG::Local.new(*args)
      instructions << instruction
      instruction
    end

    def i32
      WAG::I32Instructions.new(instructions)
    end

    def i64
      WAG::I64Instructions.new(instructions)
    end

    def memory
      WAG::MemoryInstructions.new(instructions)
    end

    def to_sexpr
      value = super()
      return value if instructions.empty?

      Array(value).concat(instructions.map(&:to_sexpr))
    end

    private

    def instructions
      @instructions ||= []
    end
  end
end
