# frozen_string_literal: true

module WAG
  module Instruction # rubocop:disable Metrics/ModuleLength
    require 'wag/instructions/base'
    require 'wag/instructions/block'
    require 'wag/instructions/br'
    require 'wag/instructions/br_if'
    require 'wag/instructions/br_table'
    require 'wag/instructions/call'
    require 'wag/instructions/call_indirect'
    require 'wag/instructions/drop'
    require 'wag/instructions/else'
    require 'wag/instructions/end'
    require 'wag/instructions/if'
    require 'wag/instructions/loop'
    require 'wag/instructions/nop'
    require 'wag/instructions/return'
    require 'wag/instructions/select'
    require 'wag/instructions/unreachable'

    require 'wag/instructions/f32/base'
    require 'wag/instructions/f32/abs'
    require 'wag/instructions/f32/add'
    require 'wag/instructions/f32/ceil'
    require 'wag/instructions/f32/const'
    require 'wag/instructions/f32/convert_i32_s'
    require 'wag/instructions/f32/convert_i32_u'
    require 'wag/instructions/f32/convert_i64_s'
    require 'wag/instructions/f32/convert_i64_u'
    require 'wag/instructions/f32/copysign'
    require 'wag/instructions/f32/demote_f64'
    require 'wag/instructions/f32/div'
    require 'wag/instructions/f32/eq'
    require 'wag/instructions/f32/floor'
    require 'wag/instructions/f32/ge'
    require 'wag/instructions/f32/gt'
    require 'wag/instructions/f32/le'
    require 'wag/instructions/f32/load'
    require 'wag/instructions/f32/lt'
    require 'wag/instructions/f32/max'
    require 'wag/instructions/f32/min'
    require 'wag/instructions/f32/mul'
    require 'wag/instructions/f32/ne'
    require 'wag/instructions/f32/nearest'
    require 'wag/instructions/f32/neg'
    require 'wag/instructions/f32/reinterpret_i32'
    require 'wag/instructions/f32/sqrt'
    require 'wag/instructions/f32/store'
    require 'wag/instructions/f32/sub'
    require 'wag/instructions/f32/trunc'

    require 'wag/instructions/f64/base'
    require 'wag/instructions/f64/abs'
    require 'wag/instructions/f64/add'
    require 'wag/instructions/f64/ceil'
    require 'wag/instructions/f64/const'
    require 'wag/instructions/f64/convert_i32_s'
    require 'wag/instructions/f64/convert_i32_u'
    require 'wag/instructions/f64/convert_i64_s'
    require 'wag/instructions/f64/convert_i64_u'
    require 'wag/instructions/f64/copysign'
    require 'wag/instructions/f64/div'
    require 'wag/instructions/f64/eq'
    require 'wag/instructions/f64/floor'
    require 'wag/instructions/f64/ge'
    require 'wag/instructions/f64/gt'
    require 'wag/instructions/f64/le'
    require 'wag/instructions/f64/load'
    require 'wag/instructions/f64/lt'
    require 'wag/instructions/f64/max'
    require 'wag/instructions/f64/min'
    require 'wag/instructions/f64/mul'
    require 'wag/instructions/f64/ne'
    require 'wag/instructions/f64/nearest'
    require 'wag/instructions/f64/neg'
    require 'wag/instructions/f64/promote_f32'
    require 'wag/instructions/f64/reinterpret_i64'
    require 'wag/instructions/f64/sqrt'
    require 'wag/instructions/f64/store'
    require 'wag/instructions/f64/sub'
    require 'wag/instructions/f64/trunc'

    require 'wag/instructions/global/base'
    require 'wag/instructions/global/get'
    require 'wag/instructions/global/set'

    require 'wag/instructions/i32/base'
    require 'wag/instructions/i32/add'
    require 'wag/instructions/i32/and'
    require 'wag/instructions/i32/clz'
    require 'wag/instructions/i32/const'
    require 'wag/instructions/i32/ctz'
    require 'wag/instructions/i32/div_s'
    require 'wag/instructions/i32/div_u'
    require 'wag/instructions/i32/eq'
    require 'wag/instructions/i32/eqz'
    require 'wag/instructions/i32/ge_s'
    require 'wag/instructions/i32/ge_u'
    require 'wag/instructions/i32/gt_s'
    require 'wag/instructions/i32/gt_u'
    require 'wag/instructions/i32/le_s'
    require 'wag/instructions/i32/le_u'
    require 'wag/instructions/i32/load'
    require 'wag/instructions/i32/load16_s'
    require 'wag/instructions/i32/load16_u'
    require 'wag/instructions/i32/load8_s'
    require 'wag/instructions/i32/load8_u'
    require 'wag/instructions/i32/lt_s'
    require 'wag/instructions/i32/lt_u'
    require 'wag/instructions/i32/mul'
    require 'wag/instructions/i32/ne'
    require 'wag/instructions/i32/or'
    require 'wag/instructions/i32/popcnt'
    require 'wag/instructions/i32/reinterpret_f32'
    require 'wag/instructions/i32/rem_s'
    require 'wag/instructions/i32/rem_u'
    require 'wag/instructions/i32/rotl'
    require 'wag/instructions/i32/rotr'
    require 'wag/instructions/i32/shl'
    require 'wag/instructions/i32/shr_s'
    require 'wag/instructions/i32/shr_u'
    require 'wag/instructions/i32/store'
    require 'wag/instructions/i32/store16'
    require 'wag/instructions/i32/store8'
    require 'wag/instructions/i32/sub'
    require 'wag/instructions/i32/trunc_f32_s'
    require 'wag/instructions/i32/trunc_f32_u'
    require 'wag/instructions/i32/trunc_f64_s'
    require 'wag/instructions/i32/trunc_f64_u'
    require 'wag/instructions/i32/wrap_i64'
    require 'wag/instructions/i32/xor'

    require 'wag/instructions/i64/base'
    require 'wag/instructions/i64/add'
    require 'wag/instructions/i64/and'
    require 'wag/instructions/i64/clz'
    require 'wag/instructions/i64/const'
    require 'wag/instructions/i64/ctz'
    require 'wag/instructions/i64/div_s'
    require 'wag/instructions/i64/div_u'
    require 'wag/instructions/i64/eq'
    require 'wag/instructions/i64/eqz'
    require 'wag/instructions/i64/extend_i32_s'
    require 'wag/instructions/i64/extend_i32_u'
    require 'wag/instructions/i64/ge_s'
    require 'wag/instructions/i64/ge_u'
    require 'wag/instructions/i64/gt_s'
    require 'wag/instructions/i64/gt_u'
    require 'wag/instructions/i64/le_s'
    require 'wag/instructions/i64/le_u'
    require 'wag/instructions/i64/load'
    require 'wag/instructions/i64/load16_s'
    require 'wag/instructions/i64/load16_u'
    require 'wag/instructions/i64/load32_s'
    require 'wag/instructions/i64/load32_u'
    require 'wag/instructions/i64/load8_s'
    require 'wag/instructions/i64/load8_u'
    require 'wag/instructions/i64/lt_s'
    require 'wag/instructions/i64/lt_u'
    require 'wag/instructions/i64/mul'
    require 'wag/instructions/i64/ne'
    require 'wag/instructions/i64/or'
    require 'wag/instructions/i64/popcnt'
    require 'wag/instructions/i64/reinterpret_f64'
    require 'wag/instructions/i64/rem_s'
    require 'wag/instructions/i64/rem_u'
    require 'wag/instructions/i64/rotl'
    require 'wag/instructions/i64/rotr'
    require 'wag/instructions/i64/shl'
    require 'wag/instructions/i64/shr_s'
    require 'wag/instructions/i64/shr_u'
    require 'wag/instructions/i64/store'
    require 'wag/instructions/i64/store16'
    require 'wag/instructions/i64/store32'
    require 'wag/instructions/i64/store8'
    require 'wag/instructions/i64/sub'
    require 'wag/instructions/i64/trunc_f32_s'
    require 'wag/instructions/i64/trunc_f32_u'
    require 'wag/instructions/i64/trunc_f64_s'
    require 'wag/instructions/i64/trunc_f64_u'
    require 'wag/instructions/i64/xor'

    require 'wag/instructions/local/base'
    require 'wag/instructions/local/get'
    require 'wag/instructions/local/set'
    require 'wag/instructions/local/tee'

    require 'wag/instructions/memory/base'
    require 'wag/instructions/memory/grow'
    require 'wag/instructions/memory/size'
  end
end
